# react-asyncmodule

webpack2+, it's recommended to use `import` method implementation code spliting, this component can help you simplify your code.

## Installation

```javascript
npm install react-asyncmodule --save
```

## Basic usage

```javascript
import AsyncModule from 'react-asyncmodule';

const Home = AsyncModule({
    load: () => import(/* webpackChunkName: "home" */ './home'),
    resolveWeak: () => require.resolveWeak('./home'),
    chunk: () => 'home',
    loading: <Loading />,
    error: <ErrorView />
});

const List = AsyncModule({
    load: () => import(/* webpackChunkName: "list" */ './list'),
    resolveWeak: () => require.resolveWeak('./list'),
    chunk: () => 'list',
    loading: <Loading />,
    error: <ErrorView />
});
```

From the above code, we will find that `loading` and `error` options are the same.

```javascript
const AsyncComponent = AsyncModule({
    loading: <Loading />,
    error: <ErrorView />
});

const Home = AsyncComponent({
    load: () => import(/* webpackChunkName: "home" */ './home'),
    resolveWeak: () => require.resolveWeak('./home'),
    chunk: () => 'home'
});

const List = AsyncModule({
    load: () => import(/* webpackChunkName: "list" */ './list'),
    resolveWeak: () => require.resolveWeak('./list'),
    chunk: () => 'list'
});
```
Good, but still lots of code duplication.

```javascript
const Home = AsyncComponent(import('./home'));
const List = AsyncComponent(import('./list'));
```

Excellent. With this [babel-plugin-asyncmodule-import](https://github.com/caoren/react-asyncmodule/tree/master/packages/asyncmodule-import), our code is much simpler.

## API

```javascript
AsyncModule(Options);
```

## Options

### load

Function, Returns a `Promise` instance. Typically generated by the `import` method provided by webpack.

### resolveWeak

Function, The moduleId that returns the current import component is automatically generated by the webpack `require.resolveWeak` method.

### loading

The component whose state is displayed during loading.

### error

Shows the components of the load error. Accept two parameters `onRetry` and `error`.


### delay

default `200`ms. `loading` component delay display, unit ms.

When the network is fast, the user does not see the loading component.

### timeout

default `120000`ms. Load timeout, unit `ms`.
